@@ -1,35 +1,24 @@
 /*
-   Copyright (C) 2000-2001 Dawit Alemayehu <adawit@kde.org>
-   Copyright (C) 2001 Rik Hemsley (rikkus) <rik@kde.org>
-   Copyright (c) 2001-2002 Marc Mutz <mutz@kde.org>
+    SPDX-FileCopyrightText: 2000-2001 Dawit Alemayehu <adawit@kde.org>
+    SPDX-FileCopyrightText: 2001 Rik Hemsley (rikkus) <rik@kde.org>
+    SPDX-FileCopyrightText: 2001-2002 Marc Mutz <mutz@kde.org>
 
-   This program is free software; you can redistribute it and/or modify
-   it under the terms of the GNU Lesser General Public License (LGPL)
-   version 2 as published by the Free Software Foundation.
+    SPDX-License-Identifier: LGPL-2.0-only
 
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU Lesser General Public License for more details.
+    RFC 1321 "MD5 Message-Digest Algorithm" Copyright (C) 1991-1992.             // krazy:exclude=copyright
+    RSA Data Security, Inc. Created 1991. All rights reserved.
 
-   You should have received a copy of the GNU Lesser General Public
-   License along with this program; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+    The KMD5 class is based on a C++ implementation of
+    "RSA Data Security, Inc. MD5 Message-Digest Algorithm" by
+    Mordechai T. Abzug,  Copyright (c) 1995.  This implementation                // krazy:exclude=copyright
+    passes the test-suite as defined in RFC 1321.
 
-   RFC 1321 "MD5 Message-Digest Algorithm" Copyright (C) 1991-1992.             // krazy:exclude=copyright
-   RSA Data Security, Inc. Created 1991. All rights reserved.
+    The encoding and decoding utilities in KCodecs with the exception of
+    quoted-printable are based on the java implementation in HTTPClient
+    package by Ronald Tschalär Copyright (C) 1996-1999.                          // krazy:exclude=copyright
 
-   The KMD5 class is based on a C++ implementation of
-   "RSA Data Security, Inc. MD5 Message-Digest Algorithm" by
-   Mordechai T. Abzug,  Copyright (c) 1995.  This implementation                // krazy:exclude=copyright
-   passes the test-suite as defined in RFC 1321.
-
-   The encoding and decoding utilities in KCodecs with the exception of
-   quoted-printable are based on the java implementation in HTTPClient
-   package by Ronald Tschalär Copyright (C) 1996-1999.                          // krazy:exclude=copyright
-
-   The quoted-printable codec as described in RFC 2045, section 6.7. is by
-   Rik Hemsley (C) 2001.
+    The quoted-printable codec as described in RFC 2045, section 6.7. is by
+    Rik Hemsley (C) 2001.
 */
 
 #include "kcodecs.h"
@@ -39,9 +28,9 @@
 #include "kcodecsqp.h"
 #include "kcodecsuuencode.h"
 #include "kcharsets.h"
+#include "kcodecs_debug.h"
 
-#include <QtCore/QCoreApplication>
-#include <QtCore/QMutex>
+#include <QMutex>
 
 #include <cassert>
 #include <cstring>
@@ -49,10 +38,9 @@
 #include <string.h>
 #include <stdlib.h>
 
-#include <QtCore/QDebug>
-#include <QtCore/QIODevice>
-#include <QtCore/QTextCodec>
-#include <QtCore/QHash>
+#include <QDebug>
+#include <QTextCodec>
+#include <QHash>
 
 #if defined(Q_OS_WIN)
 #define strncasecmp _strnicmp
@@ -61,17 +49,12 @@
 namespace KCodecs
 {
 
-static const char hexChars[16] = {
-    '0', '1', '2', '3', '4', '5', '6', '7',
-    '8', '9', 'A', 'B', 'C', 'D', 'E', 'F'
-};
-
 static QList<QByteArray> charsetCache;
 
 
 QByteArray cachedCharset(const QByteArray &name)
 {
-    foreach (const QByteArray &charset, charsetCache) {
+    for (const QByteArray &charset : qAsConst(charsetCache)) {
         if (qstricmp(name.data(), charset.data()) == 0) {
             return charset;
         }
@@ -114,11 +97,13 @@ QByteArray KCodecs::base64Encode(const QByteArray &in)
     return codec->encode(in);
 }
 
+#if KCODECS_BUILD_DEPRECATED_SINCE(5, 5)
 QByteArray KCodecs::base64Encode(const QByteArray &in, bool insertLFs)
 {
     Q_UNUSED(insertLFs);
     return base64Encode(in);
 }
+#endif
 
 void KCodecs::base64Encode(const QByteArray &in, QByteArray &out,
                            bool insertLFs)
@@ -138,16 +123,20 @@ void KCodecs::base64Decode(const QByteArray &in, QByteArray &out)
     out = base64Decode(in);
 }
 
+#if KCODECS_BUILD_DEPRECATED_SINCE(5, 56)
 QByteArray KCodecs::uuencode(const QByteArray &in)
 {
     Codec *codec = Codec::codecForName("x-uuencode");
     return codec->encode(in);
 }
+#endif
 
+#if KCODECS_BUILD_DEPRECATED_SINCE(5, 56)
 void KCodecs::uuencode(const QByteArray &in, QByteArray &out)
 {
     out = uuencode(in);
 }
+#endif
 
 QByteArray KCodecs::uudecode(const QByteArray &in)
 {
@@ -184,30 +173,30 @@ bool parseEncodedWord(const char *&scursor, const char *const send,
     char ch = *scursor++;
 
     if (ch != '?') {
-        // qDebug() << "first";
-        // qDebug() << "Premature end of encoded word";
+        // qCDebug(KCODECS_LOG) << "first";
+        // qCDebug(KCODECS_LOG) << "Premature end of encoded word";
         return false;
     }
 
     // remember start of charset (ie. just after the initial "=?") and
     // language (just after the first '*') fields:
     const char *charsetStart = scursor;
-    const char *languageStart = 0;
+    const char *languageStart = nullptr;
 
     // find delimiting '?' (and the '*' separating charset and language
     // tags, if any):
     for (; scursor != send ; scursor++) {
         if (*scursor == '?') {
             break;
-        } else if (*scursor == '*' && languageStart == 0) {
+        } else if (*scursor == '*' && languageStart == nullptr) {
             languageStart = scursor + 1;
         }
     }
 
     // not found? can't be an encoded-word!
     if (scursor == send || *scursor != '?') {
-        // qDebug() << "second";
-        // qDebug() << "Premature end of encoded word";
+        // qCDebug(KCODECS_LOG) << "second";
+        // qCDebug(KCODECS_LOG) << "Premature end of encoded word";
         return false;
     }
 
@@ -237,15 +226,15 @@ bool parseEncodedWord(const char *&scursor, const char *const send,
 
     // not found? Can't be an encoded-word!
     if (scursor == send || *scursor != '?') {
-        // qDebug() << "third";
-        // qDebug() << "Premature end of encoded word";
+        // qCDebug(KCODECS_LOG) << "third";
+        // qCDebug(KCODECS_LOG) << "Premature end of encoded word";
         return false;
     }
 
     // extract the encoding information:
     QByteArray maybeEncoding(encodingStart, scursor - encodingStart);
 
-    // qDebug() << "parseEncodedWord: found charset == \"" << maybeCharset
+    // qCDebug(KCODECS_LOG) << "parseEncodedWord: found charset == \"" << maybeCharset
     //         << "\"; language == \"" << maybeLanguage
     //         << "\"; encoding == \"" << maybeEncoding << "\"";
 
@@ -263,21 +252,21 @@ bool parseEncodedWord(const char *&scursor, const char *const send,
         if (*scursor == '?') {
             if (scursor + 1 != send) {
                 if (*(scursor + 1) != '=') {     // We expect a '=' after the '?', but we got something else; ignore
-                    // qDebug() << "Stray '?' in q-encoded word, ignoring this.";
+                    // qCDebug(KCODECS_LOG) << "Stray '?' in q-encoded word, ignoring this.";
                     continue;
                 } else { // yep, found a '?=' sequence
                     scursor += 2;
                     break;
                 }
             } else { // The '?' is the last char, but we need a '=' after it!
-                // qDebug() << "Premature end of encoded word";
+                // qCDebug(KCODECS_LOG) << "Premature end of encoded word";
                 return false;
             }
         }
     }
 
     if (*(scursor - 2) != '?' || *(scursor - 1) != '=' || scursor < encodedTextStart + 2) {
-        // qDebug() << "Premature end of encoded word";
+        // qCDebug(KCODECS_LOG) << "Premature end of encoded word";
         return false;
     }
 
@@ -292,7 +281,7 @@ bool parseEncodedWord(const char *&scursor, const char *const send,
     // try if there's a codec for the encoding found:
     Codec *codec = Codec::codecForName(maybeEncoding);
     if (!codec) {
-        // qDebug() << "Unknown encoding" << maybeEncoding;
+        // qCDebug(KCODECS_LOG) << "Unknown encoding" << maybeEncoding;
         return false;
     }
 
@@ -303,7 +292,7 @@ bool parseEncodedWord(const char *&scursor, const char *const send,
     // try if there's a (text)codec for the charset found:
     bool matchOK = false;
     QByteArray cs;
-    QTextCodec *textCodec = 0;
+    QTextCodec *textCodec = nullptr;
     if (charsetOption == KCodecs::ForceDefaultCharset || maybeCharset.isEmpty()) {
         textCodec = KCharsets::charsets()->codecForName(QLatin1String(defaultCS), matchOK);
         cs = cachedCharset(defaultCS);
@@ -321,12 +310,12 @@ bool parseEncodedWord(const char *&scursor, const char *const send,
     }
 
     if (!matchOK || !textCodec) {
-        // qDebug() << "Unknown charset" << maybeCharset;
+        // qCDebug(KCODECS_LOG) << "Unknown charset" << maybeCharset;
         delete dec;
         return false;
     };
 
-    // qDebug() << "mimeName(): \"" << textCodec->name() << "\"";
+    // qCDebug(KCODECS_LOG) << "mimeName(): \"" << textCodec->name() << "\"";
 
     // allocate a temporary buffer to store the 8bit text:
     int encodedTextLength = encodedTextEnd - encodedTextStart;
@@ -347,7 +336,7 @@ bool parseEncodedWord(const char *&scursor, const char *const send,
 
     *result = textCodec->toUnicode(buffer.data(), bbegin - buffer.data());
 
-    // qDebug() << "result now: \"" << result << "\"";
+    // qCDebug(KCODECS_LOG) << "result now: \"" << result << "\"";
     // cleanup:
     delete dec;
     *language = maybeLanguage;
@@ -539,7 +528,7 @@ QByteArray KCodecs::encodeRFC2047String(const QString &src, const QByteArray &ch
 //@cond PRIVATE
 namespace
 {
-static QHash<QByteArray, KCodecs::Codec*> *allCodecs = 0;
+static QHash<QByteArray, KCodecs::Codec*> *allCodecs = nullptr;
 Q_GLOBAL_STATIC(QMutex, dictLock)
 
 static void createCodecs()
@@ -561,7 +550,7 @@ static void cleanupCodecs()
         delete (*iter);
     }
     delete allCodecs;
-    allCodecs = 0;
+    allCodecs = nullptr;
 }
 
 }
@@ -597,7 +586,10 @@ bool KCodecs::Codec::encode(const char *&scursor, const char *const send,
 {
     // get an encoder:
     QScopedPointer<Encoder> enc(makeEncoder(newline));
-    assert(!enc.isNull());
+    if (enc.isNull()) {
+        qWarning() << "makeEncoder failed for" << name();
+        return false;
+    }
 
     // encode and check for output buffer overflow:
     while (!enc->encode(scursor, send, dcursor, dend)) {
@@ -702,10 +694,7 @@ KCodecs::Encoder::Encoder(Codec::NewlineType newline)
 {
 }
 
-KCodecs::Encoder::~Encoder()
-{
-    delete d;
-}
+KCodecs::Encoder::~Encoder() = default;
 
 bool KCodecs::Encoder::write(char ch, char*& dcursor, const char*const dend)
 {
@@ -770,8 +759,4 @@ KCodecs::Decoder::Decoder(Codec::NewlineType newline)
 {
 }
 
-KCodecs::Decoder::~Decoder()
-{
-    delete d;
-}
-
+KCodecs::Decoder::~Decoder() = default;
